==> aws-java-sdk-iot-1.11.29-sources.jar: com/amazonaws/services/iot/model/transform/ThingTypePropertiesJsonMarshaller.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not
 * use this file except in compliance with the License. A copy of the License is
 * located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.iot.model.transform;

import java.util.Map;
import java.util.List;

import com.amazonaws.AmazonClientException;
import com.amazonaws.services.iot.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.protocol.json.*;

/**
 * ThingTypePropertiesMarshaller
 */
public class ThingTypePropertiesJsonMarshaller {

    /**
     * Marshall the given parameter object, and output to a SdkJsonGenerator
     */
    public void marshall(ThingTypeProperties thingTypeProperties,
            StructuredJsonGenerator jsonGenerator) {

        if (thingTypeProperties == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        try {
            jsonGenerator.writeStartObject();

            if (thingTypeProperties.getThingTypeDescription() != null) {
                jsonGenerator.writeFieldName("thingTypeDescription")
                        .writeValue(
                                thingTypeProperties.getThingTypeDescription());
            }

            java.util.List<String> searchableAttributesList = thingTypeProperties
                    .getSearchableAttributes();
            if (searchableAttributesList != null) {
                jsonGenerator.writeFieldName("searchableAttributes");
                jsonGenerator.writeStartArray();
                for (String searchableAttributesListValue : searchableAttributesList) {
                    if (searchableAttributesListValue != null) {
                        jsonGenerator.writeValue(searchableAttributesListValue);
                    }
                }
                jsonGenerator.writeEndArray();
            }

            jsonGenerator.writeEndObject();
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }
    }

    private static ThingTypePropertiesJsonMarshaller instance;

    public static ThingTypePropertiesJsonMarshaller getInstance() {
        if (instance == null)
            instance = new ThingTypePropertiesJsonMarshaller();
        return instance;
    }

}

==> aws-java-sdk-iot-1.11.46-sources.jar: com/amazonaws/services/iot/model/transform/ThingTypePropertiesJsonMarshaller.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */
package com.amazonaws.services.iot.model.transform;

import java.util.Map;
import java.util.List;

import com.amazonaws.AmazonClientException;
import com.amazonaws.services.iot.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.protocol.json.*;

/**
 * ThingTypePropertiesMarshaller
 */
public class ThingTypePropertiesJsonMarshaller {

    /**
     * Marshall the given parameter object, and output to a SdkJsonGenerator
     */
    public void marshall(ThingTypeProperties thingTypeProperties, StructuredJsonGenerator jsonGenerator) {

        if (thingTypeProperties == null) {
            throw new AmazonClientException("Invalid argument passed to marshall(...)");
        }

        try {
            jsonGenerator.writeStartObject();

            if (thingTypeProperties.getThingTypeDescription() != null) {
                jsonGenerator.writeFieldName("thingTypeDescription").writeValue(thingTypeProperties.getThingTypeDescription());
            }

            java.util.List<String> searchableAttributesList = thingTypeProperties.getSearchableAttributes();
            if (searchableAttributesList != null) {
                jsonGenerator.writeFieldName("searchableAttributes");
                jsonGenerator.writeStartArray();
                for (String searchableAttributesListValue : searchableAttributesList) {
                    if (searchableAttributesListValue != null) {
                        jsonGenerator.writeValue(searchableAttributesListValue);
                    }
                }
                jsonGenerator.writeEndArray();
            }

            jsonGenerator.writeEndObject();
        } catch (Throwable t) {
            throw new AmazonClientException("Unable to marshall request to JSON: " + t.getMessage(), t);
        }
    }

    private static ThingTypePropertiesJsonMarshaller instance;

    public static ThingTypePropertiesJsonMarshaller getInstance() {
        if (instance == null)
            instance = new ThingTypePropertiesJsonMarshaller();
        return instance;
    }

}
